
<a id='changelog-0.2.0'></a>
# 0.2.0 — 2025-12-21

## Added

- jwcrypto integration.
- Documentation is live at https://hsmkey.rtfd.io
- Added `examples` code.

<a id='changelog-0.1.0'></a>
# 0.1.0 — 2025-12-20

## Added

- All ec, ed448, ed25519 and rsa keys for first release.
